# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`ds389`](#ds389): Set up a local 389DS server
* [`ds389::install`](#ds389--install): Set up a local 389DS server

### Defined types

#### Public Defined types

* [`ds389::instance`](#ds389--instance)
* [`ds389::instance::attr::set`](#ds389--instance--attr--set): Modifies the running directory server configuration and restarts the service when necessary.  NOTE: When calling this defined type as you fir
* [`ds389::instance::dn::add`](#ds389--instance--dn--add): Creates the passed DN using the provided paramters  NOTE: When calling this defined type as you first set up an instance, you will need to pa
* [`ds389::instance::selinux::port`](#ds389--instance--selinux--port): Consolidate selinux_port enable/disable logic
* [`ds389::instance::service`](#ds389--instance--service): Configure an instance service

#### Private Defined types

* `ds389::instance::tls`: Configure TLS for an instance

### Data types

* [`Ds389::ConfigItem`](#Ds389--ConfigItem): Valid configuration item
* [`Ds389::ConfigItems`](#Ds389--ConfigItems): Valid configuration items Hash

## Classes

### <a name="ds389"></a>`ds389`

Set up a local 389DS server

#### Parameters

The following parameters are available in the `ds389` class:

* [`service_group`](#-ds389--service_group)
* [`ldif_working_dir`](#-ds389--ldif_working_dir)
* [`instances`](#-ds389--instances)
* [`package_ensure`](#-ds389--package_ensure)
* [`config_dir`](#-ds389--config_dir)

##### <a name="-ds389--service_group"></a>`service_group`

Data type: `String[1]`

The group DS389 is installed under.

Default value: `'dirsrv'`

##### <a name="-ds389--ldif_working_dir"></a>`ldif_working_dir`

Data type: `Stdlib::Absolutepath`

A directory used for temporary storage of ldifs during
configuration.

Default value: `"${config_dir}/ldifs"`

##### <a name="-ds389--instances"></a>`instances`

Data type: `Hash`

A hash of instances to be created when the server is installed.

Default value: `{}`

##### <a name="-ds389--package_ensure"></a>`package_ensure`

Data type: `Simplib::PackageEnsure`

What to do regarding package installation

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-ds389--config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`



Default value: `'/usr/share/puppet_ds389_config'`

### <a name="ds389--install"></a>`ds389::install`

Set up a local 389DS server

#### Parameters

The following parameters are available in the `ds389::install` class:

* [`package_list`](#-ds389--install--package_list)
* [`setup_command`](#-ds389--install--setup_command)
* [`dnf_module`](#-ds389--install--dnf_module)
* [`dnf_stream`](#-ds389--install--dnf_stream)
* [`dnf_enable_only`](#-ds389--install--dnf_enable_only)
* [`dnf_profile`](#-ds389--install--dnf_profile)
* [`remove_command`](#-ds389--install--remove_command)

##### <a name="-ds389--install--package_list"></a>`package_list`

Data type: `Optional[Array[String[1]]]`

A list of packages that will installed instead of the internally selected
packages.

Default value: `undef`

##### <a name="-ds389--install--setup_command"></a>`setup_command`

Data type: `Stdlib::Unixpath`

The path to the setup command on the system

Default value: `'/sbin/setup-ds.pl'`

##### <a name="-ds389--install--dnf_module"></a>`dnf_module`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-ds389--install--dnf_stream"></a>`dnf_stream`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-ds389--install--dnf_enable_only"></a>`dnf_enable_only`

Data type: `Boolean`



Default value: `false`

##### <a name="-ds389--install--dnf_profile"></a>`dnf_profile`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-ds389--install--remove_command"></a>`remove_command`

Data type: `Stdlib::Unixpath`



Default value: `'/sbin/remove-ds.pl'`

## Defined types

### <a name="ds389--instance"></a>`ds389::instance`

The ds389::instance class.

#### Parameters

The following parameters are available in the `ds389::instance` defined type:

* [`ensure`](#-ds389--instance--ensure)
* [`base_dn`](#-ds389--instance--base_dn)
* [`root_dn`](#-ds389--instance--root_dn)
* [`listen_address`](#-ds389--instance--listen_address)
* [`port`](#-ds389--instance--port)
* [`secure_port`](#-ds389--instance--secure_port)
* [`root_dn_password`](#-ds389--instance--root_dn_password)
* [`machine_name`](#-ds389--instance--machine_name)
* [`service_user`](#-ds389--instance--service_user)
* [`service_group`](#-ds389--instance--service_group)
* [`bootstrap_ldif_content`](#-ds389--instance--bootstrap_ldif_content)
* [`ds_setup_ini_content`](#-ds389--instance--ds_setup_ini_content)
* [`general_config`](#-ds389--instance--general_config)
* [`password_policy`](#-ds389--instance--password_policy)
* [`enable_tls`](#-ds389--instance--enable_tls)
* [`tls_params`](#-ds389--instance--tls_params)

##### <a name="-ds389--instance--ensure"></a>`ensure`

Data type: `Enum['present','absent']`



Default value: `'present'`

##### <a name="-ds389--instance--base_dn"></a>`base_dn`

Data type: `Optional[String[2]]`



Default value: `undef`

##### <a name="-ds389--instance--root_dn"></a>`root_dn`

Data type: `Optional[Pattern['^[\S]+$']]`



Default value: `undef`

##### <a name="-ds389--instance--listen_address"></a>`listen_address`

Data type: `Simplib::IP`



Default value: `'127.0.0.1'`

##### <a name="-ds389--instance--port"></a>`port`

Data type: `Simplib::Port`



Default value: `389`

##### <a name="-ds389--instance--secure_port"></a>`secure_port`

Data type: `Simplib::Port`



Default value: `636`

##### <a name="-ds389--instance--root_dn_password"></a>`root_dn_password`

Data type: `Optional[Pattern['^[\S]+$']]`



Default value: `undef`

##### <a name="-ds389--instance--machine_name"></a>`machine_name`

Data type: `String[1]`



Default value: `$facts['networking']['fqdn']`

##### <a name="-ds389--instance--service_user"></a>`service_user`

Data type: `String[1]`



Default value: `'dirsrv'`

##### <a name="-ds389--instance--service_group"></a>`service_group`

Data type: `String[1]`



Default value: `'dirsrv'`

##### <a name="-ds389--instance--bootstrap_ldif_content"></a>`bootstrap_ldif_content`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-ds389--instance--ds_setup_ini_content"></a>`ds_setup_ini_content`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-ds389--instance--general_config"></a>`general_config`

Data type: `Ds389::ConfigItem`



Default value: `simplib::dlookup('ds389::instance', 'general_config', {'default_value' => {} })`

##### <a name="-ds389--instance--password_policy"></a>`password_policy`

Data type: `Ds389::ConfigItem`



Default value: `simplib::dlookup('ds389::instance', 'password_policy', {'default_value' => {} })`

##### <a name="-ds389--instance--enable_tls"></a>`enable_tls`

Data type: `Variant[Boolean, Enum['simp']]`



Default value: `simplib::lookup('simp_options::pki', { 'default_value' => false })`

##### <a name="-ds389--instance--tls_params"></a>`tls_params`

Data type: `Hash`



Default value: `simplib::dlookup('ds389::instance', 'tls_params', { 'default_value' => {} })`

### <a name="ds389--instance--attr--set"></a>`ds389::instance::attr::set`

Modifies the running directory server configuration and restarts the service
when necessary.

NOTE: When calling this defined type as you first set up an instance, you
will need to pass in all parameters since the fact will not yet be fully
populated.

#### Parameters

The following parameters are available in the `ds389::instance::attr::set` defined type:

* [`key`](#-ds389--instance--attr--set--key)
* [`value`](#-ds389--instance--attr--set--value)
* [`attrs`](#-ds389--instance--attr--set--attrs)
* [`base_dn`](#-ds389--instance--attr--set--base_dn)
* [`instance_name`](#-ds389--instance--attr--set--instance_name)
* [`root_dn`](#-ds389--instance--attr--set--root_dn)
* [`root_pw_file`](#-ds389--instance--attr--set--root_pw_file)
* [`host`](#-ds389--instance--attr--set--host)
* [`port`](#-ds389--instance--attr--set--port)
* [`force_ldapi`](#-ds389--instance--attr--set--force_ldapi)
* [`restart_instance`](#-ds389--instance--attr--set--restart_instance)

##### <a name="-ds389--instance--attr--set--key"></a>`key`

Data type: `Optional[String[1]]`

The configuration key to be set

  * You can get a list of all configuration keys by running:
    ``ldapsearch -H ldap://localhost:389 \
    -y /usr/share/puppet_ds389_config/<instance_name>_ds_pw.txt \
    -D "cn=Directory_Manager" -s base -b "cn=config"``
  * Mutually exclusive with `$attrs`
  * `$value` must be set when using this parameter.

Default value: `undef`

##### <a name="-ds389--instance--attr--set--value"></a>`value`

Data type: `Optional[String[1]]`

The value that should be set for `$key`

Default value: `undef`

##### <a name="-ds389--instance--attr--set--attrs"></a>`attrs`

Data type: `Ds389::ConfigItems`

Hash of attributes to be set.

  * You can get a list of all configuration keys by running:
    ``ldapsearch -H ldap://localhost:389 \
    -y /usr/share/puppet_ds389_config/<instance_name>_ds_pw.txt \
    -D "cn=Directory_Manager" -s base -b "cn=config"``
  * Mutually exclusive with `$key`

Default value: `{}`

##### <a name="-ds389--instance--attr--set--base_dn"></a>`base_dn`

Data type: `String[2]`

The base DN under which to search

Default value: `'cn=config'`

##### <a name="-ds389--instance--attr--set--instance_name"></a>`instance_name`

Data type: `Simplib::Systemd::ServiceName`

The Puppet resource name for the directory ``Service`` resource

##### <a name="-ds389--instance--attr--set--root_dn"></a>`root_dn`

Data type: `Optional[String[2]]`

A DN with administrative rights to the directory

* Will be determined automatically if not set

Default value: `undef`

##### <a name="-ds389--instance--attr--set--root_pw_file"></a>`root_pw_file`

Data type: `Optional[Stdlib::Absolutepath]`

A file containing the password for use with ``$root_dn``

* Defaults to `$ds389::config_dir/<usual pw file>`

Default value: `undef`

##### <a name="-ds389--instance--attr--set--host"></a>`host`

Data type: `Optional[Simplib::Host]`

The host to which to connect

* Has no effect if LDAPI is enabled on the instance
* Will use 127.0.01 if not set

Default value: `undef`

##### <a name="-ds389--instance--attr--set--port"></a>`port`

Data type: `Optional[Simplib::Port]`

The port to which to connect

* Has no effect if LDAPI is enabled on the instance
* Will be determined automatically if not set

Default value: `undef`

##### <a name="-ds389--instance--attr--set--force_ldapi"></a>`force_ldapi`

Data type: `Boolean`

Force the system to use the LDAPI interface

* Generally only useful during bootstrapping

Default value: `false`

##### <a name="-ds389--instance--attr--set--restart_instance"></a>`restart_instance`

Data type: `Boolean`

Whether or not to restart the directory server after applying this item

* This may be enabled automatically by `$attrs`

Default value: `false`

### <a name="ds389--instance--dn--add"></a>`ds389::instance::dn::add`

Creates the passed DN using the provided paramters

NOTE: When calling this defined type as you first set up an instance, you
will need to pass in all parameters since the fact will not yet be fully
populated.

If passing a full LDIF - DO NOT WRAP LINES

#### Parameters

The following parameters are available in the `ds389::instance::dn::add` defined type:

* [`instance_name`](#-ds389--instance--dn--add--instance_name)
* [`dn`](#-ds389--instance--dn--add--dn)
* [`objectclass`](#-ds389--instance--dn--add--objectclass)
* [`attrs`](#-ds389--instance--dn--add--attrs)
* [`content`](#-ds389--instance--dn--add--content)
* [`root_dn`](#-ds389--instance--dn--add--root_dn)
* [`root_pw_file`](#-ds389--instance--dn--add--root_pw_file)
* [`host`](#-ds389--instance--dn--add--host)
* [`port`](#-ds389--instance--dn--add--port)
* [`force_ldapi`](#-ds389--instance--dn--add--force_ldapi)
* [`restart_instance`](#-ds389--instance--dn--add--restart_instance)

##### <a name="-ds389--instance--dn--add--instance_name"></a>`instance_name`

Data type: `Simplib::Systemd::ServiceName`

The instance name as passed to `ds389::instance`

##### <a name="-ds389--instance--dn--add--dn"></a>`dn`

Data type: `Optional[Pattern['^\S+=.+']]`

The DN to be created

Default value: `undef`

##### <a name="-ds389--instance--dn--add--objectclass"></a>`objectclass`

Data type: `Optional[Array[String[1],1]]`

objectClasses to which the DN belongs

Default value: `undef`

##### <a name="-ds389--instance--dn--add--attrs"></a>`attrs`

Data type: `Optional[Hash[String[1],String[1],1]]`

Attributes that you wish to set at the time of creation

Default value: `undef`

##### <a name="-ds389--instance--dn--add--content"></a>`content`

Data type: `Optional[String[3]]`

The full content of the LDIF

* This may only contain *one* entry
* All other parameters will be ignored
* DO NOT add 'changetype: add'

Default value: `undef`

##### <a name="-ds389--instance--dn--add--root_dn"></a>`root_dn`

Data type: `Optional[String[2]]`

A DN with administrative rights to the directory

* Will be determined automatically if not set

Default value: `undef`

##### <a name="-ds389--instance--dn--add--root_pw_file"></a>`root_pw_file`

Data type: `Optional[Stdlib::Absolutepath]`

A file containing the password for use with ``$root_dn``

* Defaults to `$ds389::config_dir/<usual pw file>`

Default value: `undef`

##### <a name="-ds389--instance--dn--add--host"></a>`host`

Data type: `Optional[Simplib::Host]`

The host to which to connect

* Has no effect if LDAPI is enabled on the instance
* Will use 127.0.01 if not set

Default value: `undef`

##### <a name="-ds389--instance--dn--add--port"></a>`port`

Data type: `Optional[Simplib::Port]`

The port to which to connect

* Has no effect if LDAPI is enabled on the instance
* Will be determined automatically if not set

Default value: `undef`

##### <a name="-ds389--instance--dn--add--force_ldapi"></a>`force_ldapi`

Data type: `Boolean`

Force the system to use the LDAPI interface

* Generally only useful during bootstrapping

Default value: `false`

##### <a name="-ds389--instance--dn--add--restart_instance"></a>`restart_instance`

Data type: `Boolean`

Whether or not to restart the directory server after applying this item

Default value: `false`

### <a name="ds389--instance--selinux--port"></a>`ds389::instance::selinux::port`

Consolidate selinux_port enable/disable logic

#### Parameters

The following parameters are available in the `ds389::instance::selinux::port` defined type:

* [`default`](#-ds389--instance--selinux--port--default)
* [`instance`](#-ds389--instance--selinux--port--instance)
* [`enable`](#-ds389--instance--selinux--port--enable)

##### <a name="-ds389--instance--selinux--port--default"></a>`default`

Data type: `Simplib::Port`



##### <a name="-ds389--instance--selinux--port--instance"></a>`instance`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-ds389--instance--selinux--port--enable"></a>`enable`

Data type: `Boolean`



Default value: `true`

### <a name="ds389--instance--service"></a>`ds389::instance::service`

Configure an instance service

#### Parameters

The following parameters are available in the `ds389::instance::service` defined type:

* [`ensure`](#-ds389--instance--service--ensure)
* [`enable`](#-ds389--instance--service--enable)
* [`hasrestart`](#-ds389--instance--service--hasrestart)

##### <a name="-ds389--instance--service--ensure"></a>`ensure`

Data type: `Enum['stopped','running']`



Default value: `simplib::dlookup('ds389::instance::service', 'ensure', $name, { 'default_value' => 'running'})`

##### <a name="-ds389--instance--service--enable"></a>`enable`

Data type: `Boolean`



Default value: `simplib::dlookup('ds389::instance::service', 'enable', $name, { 'default_value' => true})`

##### <a name="-ds389--instance--service--hasrestart"></a>`hasrestart`

Data type: `Boolean`



Default value: `simplib::dlookup('ds389::instance::service', 'hasrestart', $name, { 'default_value' => true})`

## Data types

### <a name="Ds389--ConfigItem"></a>`Ds389::ConfigItem`

Valid configuration item

Alias of `Hash[String[1], Variant[Boolean,Integer[0],Float[0],String[1],Array[String[1],1]]]`

### <a name="Ds389--ConfigItems"></a>`Ds389::ConfigItems`

Valid configuration items Hash

Alias of `Hash[Pattern['^cn=.+'], Ds389::ConfigItem]`

